"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useSyntaxHighlighter;
var _react = require("react");
var _highlighter = require("../syntax/highlighter");
/* eslint-disable no-console */

function useSyntaxHighlighter({
  text,
  language,
  languageId,
  theme
}) {
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [error, setError] = (0, _react.useState)();
  const [isLoading, setIsLoading] = (0, _react.useState)(true);
  (0, _react.useEffect)(() => {
    let mounted = true;
    setIsLoading(true);
    async function highlight() {
      if (!text) {
        setIsLoading(false);
        setTokens([]);
        return;
      }
      try {
        const langs = Array.isArray(language) ? language : [language];
        const highlighter = await (0, _highlighter.createHighlighter)({
          langs,
          themes: [theme]
        });

        // Get first language if languageId not provided
        const firstLang = langs[0];
        const langId = languageId || (typeof firstLang === 'string' ? firstLang : typeof firstLang === 'object' && 'name' in firstLang ? firstLang.name : 'text');
        console.log('[Highlighter] Using language:', langId);
        const result = highlighter.codeToTokens(text, {
          lang: langId,
          theme
        });
        if (mounted && result.tokens) {
          console.log('[Highlighter] Generated tokens:', result.tokens.length);
          setTokens(result.tokens);
          setError(undefined);
        }
      } catch (err) {
        console.error('[Highlighter] Error:', err);
        if (mounted) {
          setError(err instanceof Error ? err.message : 'Syntax highlighting failed');
        }
      } finally {
        if (mounted) {
          setIsLoading(false);
        }
      }
    }
    highlight();
    return () => {
      mounted = false;
    };
  }, [text, language, languageId, theme]);
  return {
    tokens,
    error,
    isLoading
  };
}
//# sourceMappingURL=useSyntaxHighlighter.js.map